==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/api_guide_am64x/group__BOARD__LED__MODULE.js <==
var group__BOARD__LED__MODULE =
[
    [ "LED_Params", "structLED__Params.html", [
      [ "gpioBaseAddr", "structLED__Params.html#aa2d32d839aab9e0b92b1fe7f61d2f99d", null ],
      [ "gpioPinNum", "structLED__Params.html#a364d3a7b0bc2632f1c5d70663b4acf96", null ],
      [ "i2cInstance", "structLED__Params.html#ad462ab0d6d16f741a2fc07118d1513ca", null ],
      [ "i2cAddress", "structLED__Params.html#aa36d1bead3cc25e4bb53585a56300c45", null ],
      [ "ioIndex", "structLED__Params.html#a34f68c1dd367c3010d3f1ac2a765baa3", null ]
    ] ],
    [ "LED_Fxns", "structLED__Fxns.html", [
      [ "openFxn", "structLED__Fxns.html#a54728ac734c40551dfad2c2f8254f550", null ],
      [ "closeFxn", "structLED__Fxns.html#a51bfaeadd190536fd50f8e8e9d8c3a6a", null ],
      [ "onFxn", "structLED__Fxns.html#ab25a9ae00c0d9fbcd9c732072f1696fe", null ],
      [ "offFxn", "structLED__Fxns.html#ad0eebb6f8a7318c1064b84441a607911", null ],
      [ "setMaskFxn", "structLED__Fxns.html#a18917601e68248c0671c998f935e3202", null ]
    ] ],
    [ "LED_Attrs", "structLED__Attrs.html", [
      [ "numLedPerGroup", "structLED__Attrs.html#a1fabe3a63005410b6d76ea5c76f3d5d7", null ]
    ] ],
    [ "LED_Config", "structLED__Config.html", [
      [ "attrs", "structLED__Config.html#a30caa30c0d0c409523b0a10b524ab5e8", null ],
      [ "fxns", "structLED__Config.html#a5ffe4673e43ea56b24cb687ce8801ef4", null ],
      [ "object", "structLED__Config.html#afefeaa8dd2b92c7ce7c1cb6f7ba6dcfc", null ]
    ] ],
    [ "LED_Object", "structLED__Object.html", [
      [ "i2cHandle", "structLED__Object.html#a9877c94f86144ee4ea4eb49c8149512d", null ],
      [ "gpioBaseAddr", "structLED__Object.html#a0175b190d1cb4e789d810ad5bd1c870c", null ],
      [ "gpioPinNum", "structLED__Object.html#a641cfd758976680233b45b6d34c62e60", null ],
      [ "i2cInstance", "structLED__Object.html#a4dc5fd1c7364338dcd51e1c4af38b8e8", null ],
      [ "i2cAddress", "structLED__Object.html#aea771e63676c65b8671a6ab885145b37", null ],
      [ "ioIndex", "structLED__Object.html#a940a72eec63e8dbd90e99a0e5e6a724a", null ]
    ] ],
    [ "LED_Handle", "group__BOARD__LED__MODULE.html#gaa809d3bdb4311021a94536d8b2d7f858", null ],
    [ "LED_Config", "group__BOARD__LED__MODULE.html#ga08f821b83201d4bec654350784e3aeb6", null ],
    [ "LED_Params", "group__BOARD__LED__MODULE.html#ga37136f9dced6cb2fb7eb06e44b6d25af", null ],
    [ "LED_OpenFxn", "group__BOARD__LED__MODULE.html#ga0f7a1b03d7a213418786bbc4d73b2838", null ],
    [ "LED_CloseFxn", "group__BOARD__LED__MODULE.html#gac2257ad05062f254c59f276eb029f0e9", null ],
    [ "LED_OnFxn", "group__BOARD__LED__MODULE.html#ga96dcc05e70380f9446ece198a54c486e", null ],
    [ "LED_OffFxn", "group__BOARD__LED__MODULE.html#ga9d4c7864200910f405c1567fcdebb621", null ],
    [ "LED_SetMaskFxn", "group__BOARD__LED__MODULE.html#ga8c55ad8073e10adfe204156e89f232aa", null ],
    [ "LED_Params_init", "group__BOARD__LED__MODULE.html#gaff04caa98eb18018bc7cec02e89fea86", null ],
    [ "LED_open", "group__BOARD__LED__MODULE.html#ga3023e172ec2251f4f47c6d2206c9f99e", null ],
    [ "LED_close", "group__BOARD__LED__MODULE.html#gaed3a98fc00b969a9a54f71902f6a9a53", null ],
    [ "LED_on", "group__BOARD__LED__MODULE.html#ga7c1c43e232657b067beecaeb961084b3", null ],
    [ "LED_off", "group__BOARD__LED__MODULE.html#ga6366c208b93cf41c8396913530d14bdf", null ],
    [ "LED_setMask", "group__BOARD__LED__MODULE.html#ga0531576afbc2444e2d359ae894ad0020", null ],
    [ "LED_getAttrs", "group__BOARD__LED__MODULE.html#ga7729b0edc0b28507257ed5369c4e7272", null ]
];

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/api_guide_am64x/group__BOARD__LED__MODULE.js <==
var group__BOARD__LED__MODULE =
[
    [ "LED_Params", "structLED__Params__s.html", [
      [ "gpioBaseAddr", "structLED__Params__s.html#aa2d32d839aab9e0b92b1fe7f61d2f99d", null ],
      [ "gpioPinNum", "structLED__Params__s.html#a364d3a7b0bc2632f1c5d70663b4acf96", null ],
      [ "i2cInstance", "structLED__Params__s.html#ad462ab0d6d16f741a2fc07118d1513ca", null ],
      [ "i2cAddress", "structLED__Params__s.html#aa36d1bead3cc25e4bb53585a56300c45", null ],
      [ "ioIndex", "structLED__Params__s.html#a34f68c1dd367c3010d3f1ac2a765baa3", null ]
    ] ],
    [ "LED_Fxns", "structLED__Fxns.html", [
      [ "openFxn", "structLED__Fxns.html#a54728ac734c40551dfad2c2f8254f550", null ],
      [ "closeFxn", "structLED__Fxns.html#a51bfaeadd190536fd50f8e8e9d8c3a6a", null ],
      [ "onFxn", "structLED__Fxns.html#ab25a9ae00c0d9fbcd9c732072f1696fe", null ],
      [ "offFxn", "structLED__Fxns.html#ad0eebb6f8a7318c1064b84441a607911", null ],
      [ "setMaskFxn", "structLED__Fxns.html#a18917601e68248c0671c998f935e3202", null ]
    ] ],
    [ "LED_Attrs", "structLED__Attrs.html", [
      [ "numLedPerGroup", "structLED__Attrs.html#a1fabe3a63005410b6d76ea5c76f3d5d7", null ]
    ] ],
    [ "LED_Config", "structLED__Config__s.html", [
      [ "attrs", "structLED__Config__s.html#a30caa30c0d0c409523b0a10b524ab5e8", null ],
      [ "fxns", "structLED__Config__s.html#a5ffe4673e43ea56b24cb687ce8801ef4", null ],
      [ "object", "structLED__Config__s.html#afefeaa8dd2b92c7ce7c1cb6f7ba6dcfc", null ]
    ] ],
    [ "LED_Object", "structLED__Object.html", [
      [ "i2cHandle", "structLED__Object.html#a9877c94f86144ee4ea4eb49c8149512d", null ],
      [ "gpioBaseAddr", "structLED__Object.html#a0175b190d1cb4e789d810ad5bd1c870c", null ],
      [ "gpioPinNum", "structLED__Object.html#a641cfd758976680233b45b6d34c62e60", null ],
      [ "i2cInstance", "structLED__Object.html#a4dc5fd1c7364338dcd51e1c4af38b8e8", null ],
      [ "i2cAddress", "structLED__Object.html#aea771e63676c65b8671a6ab885145b37", null ],
      [ "ioIndex", "structLED__Object.html#a940a72eec63e8dbd90e99a0e5e6a724a", null ]
    ] ],
    [ "LED_Handle", "group__BOARD__LED__MODULE.html#gaa809d3bdb4311021a94536d8b2d7f858", null ],
    [ "LED_OpenFxn", "group__BOARD__LED__MODULE.html#ga0f7a1b03d7a213418786bbc4d73b2838", null ],
    [ "LED_CloseFxn", "group__BOARD__LED__MODULE.html#gac2257ad05062f254c59f276eb029f0e9", null ],
    [ "LED_OnFxn", "group__BOARD__LED__MODULE.html#ga96dcc05e70380f9446ece198a54c486e", null ],
    [ "LED_OffFxn", "group__BOARD__LED__MODULE.html#ga9d4c7864200910f405c1567fcdebb621", null ],
    [ "LED_SetMaskFxn", "group__BOARD__LED__MODULE.html#ga8c55ad8073e10adfe204156e89f232aa", null ],
    [ "LED_Params_init", "group__BOARD__LED__MODULE.html#gaff04caa98eb18018bc7cec02e89fea86", null ],
    [ "LED_open", "group__BOARD__LED__MODULE.html#ga3023e172ec2251f4f47c6d2206c9f99e", null ],
    [ "LED_close", "group__BOARD__LED__MODULE.html#gaed3a98fc00b969a9a54f71902f6a9a53", null ],
    [ "LED_on", "group__BOARD__LED__MODULE.html#ga7c1c43e232657b067beecaeb961084b3", null ],
    [ "LED_off", "group__BOARD__LED__MODULE.html#ga6366c208b93cf41c8396913530d14bdf", null ],
    [ "LED_setMask", "group__BOARD__LED__MODULE.html#ga0531576afbc2444e2d359ae894ad0020", null ],
    [ "LED_getAttrs", "group__BOARD__LED__MODULE.html#ga7729b0edc0b28507257ed5369c4e7272", null ]
];
